# COOPER to InfluxDB

[![Travis](https://img.shields.io/travis/hardwario/cp2influxdb/master.svg)](https://travis-ci.org/hardwario/cp2influxdb)
[![Release](https://img.shields.io/github/release/hardwario/cp2influxdb.svg)](https://github.com/hardwario/cp2influxdb/releases)
[![License](https://img.shields.io/github/license/hardwario/cp2influxdb.svg)](https://github.com/hardwario/cp2influxdb/blob/master/LICENSE)

## Installing

You can install **cp2influxdb** directly from PyPI:

```sh
sudo pip3 install -U cp2influxdb
```

## Usage

Update config.yml and run

```sh
cp2influxdb -c config.yml
```

## License

This project is licensed under the [**MIT License**](https://opensource.org/licenses/MIT/) - see the [**LICENSE**](LICENSE) file for details.
